@@ -16,7 +16,7 @@ This is a [PyTorch](https://pytorch.org) implementation of paper
  along with [Dueling Network](model.html), [Prioritized Replay](replay_buffer.html)
  and Double Q Network.
 
-Here are the [experiment](experiment.html) and [model](model.html) implementation.
+Here is the [experiment](experiment.html) and [model](model.html) implementation.
 
 \(
    \def\green#1{{\color{yellowgreen}{#1}}}
